core/shared/solo_pue_page library
Classes
- SoloPuePage
-
This widget can be used as a base for laying out your page. It is
similar to
PuePage, but doesn't modify a parentPueprint. It also renders everything itself, without the help of a parentPueprint.